@@ -7,7 +7,7 @@ import sys, types, inspect, functools
 from functools import lru_cache
 from importlib import import_module
 
-__version__ = 1.8
+__version__ = 1.9
 
 class TypeCheckError(Exception): 
     pass
@@ -36,7 +36,7 @@ def _resolve_type(self, obj):
     elif obj in (True, False):
         return bool
     elif obj.__class__ is tuple:
-        return tuple([_resolve_type(t) for t in obj])
+        return tuple([_resolve_type(self, t) for t in obj])
     elif obj.__class__ is str and '.' in obj:
         if self and obj.startswith('self.'):
             return _resolve_type(self, getattr(self, obj[5:]))
